# earthkit.time

:warning: This project is BETA and will be experimental for the foreseeable
future. Interfaces and functionality are likely to change, and the project
itself may be scrapped. DO NOT use this software in any project/software that is
operational.

Date and time manipulation routines for the use of weather data

## License
[Apache License 2.0](LICENSE) In applying this licence, ECMWF does not waive the privileges and immunities
granted to it by virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.